==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/blg_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="blg_item.php" method="post">
<input type="hidden" name="user_id" value="<?php echo $author['user_id'];?>" />
<input type="hidden" name="blog_id" value="<?php if (isset($blog)) {echo $blog['blog_id'];}?>" />

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<?php
		if (isset($group) || isset($profile)) {
		?>
		<td width="180" valign="top">
			<?php
			if (isset($group)) {
			include $templatePath . "g_menu.inc.tpl.php";
			}
			elseif (isset($profile)) {
			include $templatePath . "sn_menu.inc.tpl.php";
			}
			?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>
		
		<td width="560" valign="top">
		<?php 
		}
		else {
		?>
		
		<td width="760" valign="top">
		<?php }?>
			<div class="box_top">
				<?php echo $lang['hdr_blog'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<?php
			if (isset($blog)) {
			?>
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td>
						<?php
						if (isset($group)) {
						?>
						<a href="g_member_profile.php?group_id=<?php echo $group['group_id'];?>&amp;user_id=<?php echo $author['user_id'];?>"><?php echo $author['profile_nic'];?></a>:&nbsp;
						<?php }?>
						<?php 
						echo $blog['blog_create_datetime'];
						
						if ($blog['blog_create_datetime'] != $blog['blog_edit_datetime'] && !empty($blog['blog_edit_datetime'])) {
						    echo " (" . $lang['txt_last_edited'] . ": " . $blog['blog_edit_datetime'] . ")";
						}
						?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="12" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $blog['blog_title'];?><br />
						</span>
						<?php echo $blog['blog_body_display'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<?php 
			}
			if (isset($blogs)) {
			?>
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<tr>
					<td colspan="3">
						<b><?php echo $lang['hdr_recent'];?></b><br />
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
					</td>
				</tr>
				<?
				foreach($blogs as $key => $i):
				if (isset($blog) && $blog['blog_id'] != $i['blog_id']) {
				?>
				<tr>
					<td valign="top" nowrap="nowrap">
						<?php
						if (isset($group)) {
						?>
						<a href="blg_item.php?group_id=<?php echo $group['group_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
						<?
						}
						elseif (isset($profile)) {
						?>
						<a href="blg_item.php?user_id=<?php echo $i['user_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
						<?php
						}
						else {
						?>
						<a href="blg_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
						<?php }?>
					</td>
					<td valign="top">
						<?php echo $i['blog_title'];?><br />
					</td>
					<td valign="top">
						<?php echo $lang['href_comments'];?>&nbsp;(<?php if (!empty($i['comment_total'])) { echo $i['comment_total'];} else { echo "0";}?>)
						<br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				?>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
					</td>
				</tr>
			</table>
			<?php 
			}
			else {
				echo $lang['err_no_blog'] . "<br />";
			}
			?>
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<tr>
					<td>
						<div class="box_edit">
							<span style="float: right">
							<?php
							if (isset($blog)) {
								if (isset($group)) {
									if ($this->group_acs->checkPermission($resource_ids['group_blog'], $privilege_ids['allow_edit']) && isset($blog['blog_id'])) {
									?>
										<a href="blg_edit.php?group_id=<?php echo $group['group_id'];?>&amp;blog_id=<?php echo $blog['blog_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
									<?php }?>
									&nbsp;
									<a href="blg_list.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_blog_list'];?></a>
									&nbsp;
									<a href="blg_item.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_latest_blog'];?></a>
								<?php
								} else {
									if (isset($blog['user_id']) && $blog['user_id'] == $me['user_id']) {
										if (!empty($blog['group_id'])) {
								?>
									<a href="blg_item.php?group_id=<?php echo $blog['group_id'];?>&amp;blog_id=<?php echo $blog['blog_id'];?>" class="link_stnd"><?php echo $lang['href_goto_group'];?></a>
								<?php 
									}
									else {
									?>
									<a href="blg_edit.php?blog_id=<?php echo $blog['blog_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
								<?php }?>
								&nbsp;
								<?php }?>
								<a href="blg_list.php?user_id=<?php echo $blog['user_id'];?>" class="link_stnd"><?php echo $lang['href_blog_list'];?></a>
								&nbsp;
								<a href="blg_item.php?user_id=<?php echo $blog['user_id'];?>" class="link_stnd"><?php echo $lang['href_latest_blog'];?></a>
								<?php
								}
							}
							?>
							
							
							<?php
							// ADD BUTTON
							if (isset($group) && $this->group_acs->checkPermission($resource_ids['group_blog'], $privilege_ids['allow_edit'])) { //resource_id, Priv_id
							?>
							&nbsp;<a href="blg_edit.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_add_blog'];?></a>
							<?php 
							}
							elseif (!isset($author) || $author['user_id'] == $me['user_id']) {
							?>
							&nbsp;<a href="blg_edit.php" class="link_stnd"><?php echo $lang['href_add_blog'];?></a>
							<?php }?>
							<br />
							</span>
							<?php
							if (isset($blog['rsp'])) {
								echo "<b>" . $lang['txt_published_to']. ": </b>";
							    foreach($blog['rsp'] as $key => $i):
									
									echo trim($lang['rsp']['rsp_level'][$i['level_id']] . " " . $i['degree_id']);
									echo " (" .$lang['rsp']['status'][$i['status_id']] . ")";
									if ($key+1 < count($blog['rsp'])) {
									    echo ", ";
									}
									
								endforeach;
							}
							?><br />
						</div>
					</td>
				</tr>
			</table>
			<?php
			if (isset($blog['blog_id'])) {
				//comments
				if ($blog['user_id'] == $me['user_id']) {
					$unlocked = 1;
				}
					
				if (isset($group)) {
					if ($this->group_acs->checkPermission($resource_ids['group_blog'], $privilege_ids['allow_comment'])) {
					    $unlocked = 1;
					}
					
					$hidden_form = array(
						"blog_id" => $blog['blog_id'], 
						"group_id" => $group['group_id']
					);
					
					$requested_comment_language_id = $group['language_id'];
				}
				else {
					if (!empty($blog['blog_allow_comments'])) {
					    $unlocked = 1;
					}
					
					$hidden_form = array(
						"blog_id" => $blog['blog_id']
					);
					
					$requested_comment_language_id = $me['language_id'];
				}
				
				include $templatePath . "comment.inc.tpl.php";
			}
			?>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/template/barnraiser_01/blg_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="blg_item.php" method="post">
<input type="hidden" name="user_id" value="<?php echo $author['user_id'];?>" />
<input type="hidden" name="blog_id" value="<?php if (isset($blog)) {echo $blog['blog_id'];}?>" />

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<?php
		if (isset($group) || isset($profile)) {
		?>
		<td width="180" valign="top">
			<?php
			if (isset($group)) {
			include $templatePath . "g_menu.inc.tpl.php";
			}
			elseif (isset($profile)) {
			include $templatePath . "sn_menu.inc.tpl.php";
			}
			?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>
		
		<td width="560" valign="top">
		<?php 
		}
		else {
		?>
		
		<td width="760" valign="top">
		<?php }?>
			<div class="box_top">
				<?php echo $lang['hdr_blog'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<?php
			if (isset($blog)) {
			?>
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td>
						<?php
						if (isset($group)) {
						?>
						<a href="g_member_profile.php?group_id=<?php echo $group['group_id'];?>&amp;user_id=<?php echo $author['user_id'];?>"><?php echo $author['profile_nic'];?></a>:&nbsp;
						<?php }?>
						<?php 
						echo $blog['blog_create_datetime'];
						
						if ($blog['blog_create_datetime'] != $blog['blog_edit_datetime'] && !empty($blog['blog_edit_datetime'])) {
						    echo " (" . $lang['txt_last_edited'] . ": " . $blog['blog_edit_datetime'] . ")";
						}
						?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="12" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $blog['blog_title'];?><br />
						</span>
						<?php echo $blog['blog_body_display'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<?php 
			}
			if (isset($blogs)) {
			?>
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<tr>
					<td colspan="3">
						<b><?php echo $lang['hdr_recent'];?></b><br />
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
					</td>
				</tr>
				<?
				foreach($blogs as $key => $i):
				if (isset($blog) && $blog['blog_id'] != $i['blog_id']) {
				?>
				<tr>
					<td valign="top" nowrap="nowrap">
						<?php
						if (isset($group)) {
						?>
						<a href="blg_item.php?group_id=<?php echo $group['group_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
						<?
						}
						elseif (isset($profile)) {
						?>
						<a href="blg_item.php?user_id=<?php echo $i['user_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
						<?php
						}
						else {
						?>
						<a href="blg_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
						<?php }?>
					</td>
					<td valign="top">
						<?php echo $i['blog_title'];?><br />
					</td>
					<td valign="top">
						<?php echo $lang['href_comments'];?>&nbsp;(<?php if (!empty($i['comment_total'])) { echo $i['comment_total'];} else { echo "0";}?>)
						<br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				?>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
					</td>
				</tr>
			</table>
			<?php 
			}
			else {
				echo $lang['err_no_blog'] . "<br />";
			}
			?>
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<tr>
					<td>
						<div class="box_edit">
							<span style="float: right">
							<?php
							if (isset($blog)) {
								if (isset($group)) {
									if ($this->group_acs->checkPermission($resource_ids['group_blog'], $privilege_ids['allow_edit']) && isset($blog['blog_id'])) {
									?>
										<a href="blg_edit.php?group_id=<?php echo $group['group_id'];?>&amp;blog_id=<?php echo $blog['blog_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
									<?php }?>
									&nbsp;
									<a href="blg_list.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_blog_list'];?></a>
									&nbsp;
									<a href="blg_item.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_latest_blog'];?></a>
								<?php
								} else {
									if (isset($blog['user_id']) && $blog['user_id'] == $me['user_id']) {
										if (!empty($blog['group_id'])) {
								?>
									<a href="blg_item.php?group_id=<?php echo $blog['group_id'];?>&amp;blog_id=<?php echo $blog['blog_id'];?>" class="link_stnd"><?php echo $lang['href_goto_group'];?></a>
								<?php 
									}
									else {
									?>
									<a href="blg_edit.php?blog_id=<?php echo $blog['blog_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
								<?php }?>
								&nbsp;
								<?php }?>
								<a href="blg_list.php?user_id=<?php echo $blog['user_id'];?>" class="link_stnd"><?php echo $lang['href_blog_list'];?></a>
								&nbsp;
								<a href="blg_item.php?user_id=<?php echo $blog['user_id'];?>" class="link_stnd"><?php echo $lang['href_latest_blog'];?></a>
								<?php
								}
							}
							?>
							
							<?php
							// ADD BUTTON
							if (isset($group) && $this->group_acs->checkPermission($resource_ids['group_blog'], $privilege_ids['allow_edit'])) { //resource_id, Priv_id
							?>
							&nbsp;<a href="blg_edit.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_add_blog'];?></a>
							<?php 
							}
							elseif (isset($profile) && $profile['user_id'] == $me['user_id'] || isset($author) && $author['user_id'] == $me['user_id'] || (!isset($author) && !isset($profile))) {
							?>
							&nbsp;<a href="blg_edit.php" class="link_stnd"><?php echo $lang['href_add_blog'];?></a>
							<?php }?>
							<br />
							</span>
							<?php
							if (isset($blog['rsp'])) {
								echo "<b>" . $lang['txt_published_to']. ": </b>";
							    foreach($blog['rsp'] as $key => $i):
									
									echo trim($lang['rsp']['rsp_level'][$i['level_id']] . " " . $i['degree_id']);
									echo " (" .$lang['rsp']['status'][$i['status_id']] . ")";
									if ($key+1 < count($blog['rsp'])) {
									    echo ", ";
									}
									
								endforeach;
							}
							?><br />
						</div>
					</td>
				</tr>
			</table>
			<?php
			if (isset($blog['blog_id'])) {
				//comments
				if ($blog['user_id'] == $me['user_id']) {
					$unlocked = 1;
				}
					
				if (isset($group)) {
					if ($this->group_acs->checkPermission($resource_ids['group_blog'], $privilege_ids['allow_comment'])) {
					    $unlocked = 1;
					}
					
					$hidden_form = array(
						"blog_id" => $blog['blog_id'], 
						"group_id" => $group['group_id']
					);
					
					$requested_comment_language_id = $group['language_id'];
				}
				else {
					if (!empty($blog['blog_allow_comments'])) {
					    $unlocked = 1;
					}
					
					$hidden_form = array(
						"blog_id" => $blog['blog_id']
					);
					
					$requested_comment_language_id = $me['language_id'];
				}
				
				include $templatePath . "comment.inc.tpl.php";
			}
			?>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>
